Creates a submatrix of the same tensor as W_kappa_ij, but this time l,k give the indices of the observations, not variables.
W_kappa_lk(design, theta, i1, i2, ct)The matrix representing the result of the integration.
matrix of design points
lengthscales
index of the observations (WARNING: starts at 0)
Covariance type, 1 means Gaussian, 2 means Matern 3/2, 3 means Matern 5/2