Given an m dimensional function whose inputs live in bounded intervals [a1, b1], ..., [am, bm], return a wrapped version of the function whose inputs live in R^m. Transformed using the logit function.
domain_to_R(f, domain)A function wrapping f.
The function to wrap, should have a single vector-valued input.
A list of real tuples, indicating the original domain of the function.