Create a single element of the BETA/GAMMA matrix. Used to compute acquisition functions and their gradients.
get_betagamma(C, xnew, grad = FALSE)If grad == FALSE, A numeric vector of length 2, whose first element of beta_ij and the second gamma_ij.
If grad == TRUE, a list with 3 numeric vector elements, the first giving the gradient for beta_ij, and the second for gamma_ij,
and the third is the same vector as would have been returned if grad was FALSE: simply the values of beta and gamma.
A const_C object, the result of a call to C_GP
The new design point
If FALSE, calculate beta and gamma only. If TRUE, calculate their gradient too.