Learn R Programming

activegp (version 1.1.1)

logLikHessian: Hessian of the log-likelihood with respect to lengthscales hyperparameters Works for homGP and hetGP models from the hetGP package for now.

Description

Hessian of the log-likelihood with respect to lengthscales hyperparameters Works for homGP and hetGP models from the hetGP package for now.

Usage

logLikHessian(model)

Value

A matrix giving the Hessian of the GP loglikelihood.

Arguments

model

homGP model